@@ -35,7 +35,7 @@ This module provides several classes for performing spell checking
 via the Enchant spellchecking library.  For more details on Enchant,
 visit the project website:
 
-    http://www.abisource.com/enchant/
+    https://abiword.github.io/enchant/
 
 Spellchecking is performed using 'Dict' objects, which represent
 a language dictionary.  Their use is best demonstrated by a quick
@@ -72,7 +72,7 @@ of 'Error'.
 """
 _DOC_ERRORS = ["enchnt", "enchnt", "incant", "fr"]
 
-__version__ = "3.1.1"
+__version__ = "3.2.1"
 
 import os
 import warnings
@@ -89,7 +89,7 @@ from enchant.utils import get_default_language
 from enchant.pypwl import PyPWL
 
 
-class ProviderDesc(object):
+class ProviderDesc:
     """Simple class describing an Enchant provider.
 
     Each provider has the following information associated with it:
@@ -122,7 +122,7 @@ class ProviderDesc(object):
         return hash(self.name + self.desc + self.file)
 
 
-class _EnchantObject(object):
+class _EnchantObject:
     """Base class for enchant objects.
 
     This class implements some general functionality for interfacing with
@@ -158,12 +158,12 @@ class _EnchantObject(object):
     def _raise_error(self, default="Unspecified Error", eclass=Error):
         """Raise an exception based on available error messages.
 
-         This method causes an Error to be raised.  Subclasses should
-         override it to retrieve an error indication from the underlying
-         API if possible.  If such a message cannot be retrieved, the
-         argument value <default> is used.  The class of the exception
-         can be specified using the argument <eclass>
-         """
+        This method causes an Error to be raised.  Subclasses should
+        override it to retrieve an error indication from the underlying
+        API if possible.  If such a message cannot be retrieved, the
+        argument value <default> is used.  The class of the exception
+        can be specified using the argument <eclass>
+        """
         raise eclass(default)
 
     _raise_error._DOC_ERRORS = ["eclass"]
@@ -205,7 +205,7 @@ class Broker(_EnchantObject):
         This method is the constructor for the 'Broker' object.  No
         arguments are required.
         """
-        _EnchantObject.__init__(self)
+        super().__init__()
 
     def _init_this(self):
         self._this = _e.broker_init()
@@ -222,7 +222,7 @@ class Broker(_EnchantObject):
             pass
 
     def __getstate__(self):
-        state = super(Broker, self).__getstate__()
+        state = super().__getstate__()
         state.pop("_live_dicts")
         return state
 
@@ -539,7 +539,7 @@ class Dict(_EnchantObject):
             broker = _broker
         self._broker = broker
         # Now let the superclass initialise the C-library object
-        _EnchantObject.__init__(self)
+        super().__init__()
 
     def _init_this(self):
         # Create dead object if False was given as the tag.
@@ -554,7 +554,7 @@ class Dict(_EnchantObject):
         # Calling free() might fail if python is shutting down
         try:
             self._free()
-        except AttributeError:
+        except (AttributeError, TypeError):
             pass
 
     def _switch_this(self, this, broker):
@@ -591,7 +591,7 @@ class Dict(_EnchantObject):
         """
         if self._broker is None or self._broker._this is None:
             self._this = None
-        _EnchantObject._check_this(self, msg)
+        super()._check_this(msg)
 
     def _raise_error(self, default="Unspecified Error", eclass=Error):
         """Overrides _EnchantObject._raise_error to check dict errors."""
@@ -778,7 +778,7 @@ class DictWithPWL(Dict):
         exclude list.  If this file does not exist, it is created with
         default permissions.
         """
-        Dict.__init__(self, tag, broker)
+        super().__init__(tag, broker)
         if pwl is not None:
             if not os.path.exists(pwl):
                 f = open(pwl, "wt")
@@ -802,7 +802,7 @@ class DictWithPWL(Dict):
             self._free()
         if self.pel is None:
             self._free()
-        Dict._check_this(self, msg)
+        super()._check_this(msg)
         self.pwl._check_this(msg)
         self.pel._check_this(msg)
 
@@ -814,7 +814,7 @@ class DictWithPWL(Dict):
         if self.pel is not None:
             self.pel._free()
             self.pel = None
-        Dict._free(self)
+        super()._free()
 
     def check(self, word):
         """Check spelling of a word.
@@ -827,7 +827,7 @@ class DictWithPWL(Dict):
             return False
         if self.pwl.check(word):
             return True
-        if Dict.check(self, word):
+        if super().check(word):
             return True
         return False
 
@@ -837,7 +837,7 @@ class DictWithPWL(Dict):
         This method tries to guess the correct spelling for a given
         word, returning the possibilities in a list.
         """
-        suggs = Dict.suggest(self, word)
+        suggs = super().suggest(word)
         suggs.extend([w for w in self.pwl.suggest(word) if w not in suggs])
         for i in range(len(suggs) - 1, -1, -1):
             if self.pel.check(suggs[i]):
